# Försäkringskassans Leverera kundavisering (LEKA) - Testmiljö

E-tjänsten _Leverera kundavisering_ (LEKA) notifierar anslutna organisationer om förändringar av Försäkringskassans och Pensionsmyndighetens kunders ärenden och uppgifter, vilka sedan kan hämtas via e-tjänsten _Leverera förmånsinformation_ (LEFI). Det här arkivet samlar den information som behövs för att fysiskt ansluta till och nyttja Försäkringskassans produktionsmiljö för LEKA, vilken inkluderar API-specifikationer, URL:er och beskrivningar.

Mer information om LEKA och LEFI hittar du på https://www.forsakringskassan.se/myndigheter-och-samarbetspartner/e-tjanster-for-myndigheter-och-samarbetspartner/lefi-online.

## Innehållsförteckning
1. Tjänstebeskrivning
    - 1.1 Prenumeration
    - 1.2 Avisering
2. Miljöbeskrivning
    - 2.1 Anslutning

## 1. Tjänstebeskrivning

LEKA låter en ansluten organisation, såsom ett försäkringsbolag eller en kommun, att hantera _prenumerationer_ på _aviseringar_ om uppdaterade ärenden eller tillkomna uppgifter om Försäkringskassans kunder. Aviseringarna i sig innehåller inte den nya informationen. Istället förutsätts mottagaren av respektive avisering själv hämta informationen via e-tjänsten [LEFI:s][LEFI] gränssnitt.

[LEFI]: https://www.forsakringskassan.se/myndigheter-och-samarbetspartner/e-tjanster-for-myndigheter-och-samarbetspartner/lefi-online

Prenumerationer och aviseringar hanteras respektive hämtas via de två HTTP-baserade gränssnitt som beskrivs i de följande underavsnitten. De båda tjänsternas _OpenAPI-specifikationer_, vilka är programmatiska beskrivningar av gränssnittens operationer och datatyper, finns att hitta i mappen `openapi/`.

### 1.1 Prenumeration

Gränssnittet låter en ansluten organisation skapa, hämta och ta bort _prenumerationer_ på aviseringar. Varje sådan prenumeration rör en kund hos Försäkringskassan, identifierad med personnummer, och innehåller en lista av de kategorier av socialförsäkringsinformation, eller _förmåner_, prenumeranten önskar bli aviserad om.

Det finns inte möjlighet att prenumerara på alla förmåner det går att hämta information om via [LEFI][LEFI]. Detta är en begränsning i den aktuella versionen av LEKA. Dessutom sker görs också begränsningar i förmedlade förmåner baserat på det _regelverk för utlämnande_ som beslutats av Försäkringskassan för respektive organisation.

### 1.2 Avisering

Gränssnittet låter en ansluten organisation __hämta__ _aviseringar_ associerade med skapade och aktiva prenumerationer. Notera att LEKA alltså _inte_ skickar ut aviseringarna till organisationernas servrar, utan samlar dem i virtuella brelådor respektive organisation måste tömma regelbundet på egen hand. Aviseringar bör inte hämtas oftare än var 10:e sekund för integrationstester som körs under kortare perioder. Pågår ett test i flera timmar eller längre bör inte aviseringar hämtas oftare än en gång i timmen.

Kunder hos Försäkringskassan kan av olika anledningar avregistreras eller få sina personnummer utbytta. Om detta påträffar samtidigt som det finns en prenumeration på den kunden meddelas prenumeranten igenom en speciell avisering, varefter prenumerationen avaktiveras permanent.

Aviseringar kan hämtas _flera gånger_. Dock finns begränsningen att en avisering som inte hämtats kommer att gallras _en vecka efter att den skapats_ i LEKA. Likaså kommer en avisering som hämtats gallras _en vecka efter att den hämtats den första gången_ från LEKA. 

## 2. Miljöbeskrivning

Anslutning till LEKA i produktionsmiljö förutsätter anslutning till LEFI:s produktionsmiljö. Anslutningsprocessen finns beskriven på [websidan för LEFI Online][LEFI].

### 2.1 Anslutning

Nyttjande av LEKA:s produktionsmiljö kräver även att en HTTPS-klient används som är konfigurerad att använda ett klient-certifikat som godkänns av Försäkringskassan. Instruktioner om hur ett godkänt certifikat erhålls, samt vilka certifikat som måste betraktas som betrodda, finns på [websidan för LEFI Online][LEFI].

#### 2.1.1 Gränssnittens URL:er

När ett godkänt certifikat är på plats (och HTTPS-klienten i fråga är konfigurerad att använda det med mTLS) ska följande bas-URL:er användas för att skicka meddelanden till de båda gränssnitten.

| Gränssnitt    | Bas-URL                                                                                   |
|:--------------|:------------------------------------------------------------------------------------------|
| Prenumeration | https://fmansinfo.forsakringskassan.se:7020/rest/FK.EXI.LevereraKundAvisering.Prenumeration.V9/ |
| Avisering     | https://fmansinfo.forsakringskassan.se:7020/rest/FK.EXI.LevereraKundAvisering.Avisering.V9/     |

En bas-URL är alltså en URL som saknar sökvägen från en specifik API-operation. För att, exempelvis, skicka ett meddelande till aviseringsgränssnittets operation `hamtaAviseringar`, vilken har sökvägen `/leka-extern-avisering/v9/aktorer/{aktorsId}/aviseringar`, måste följande sökväg användas:

```
https://fmansinfo.forsakringskassan.se:7020/rest/FK.EXI.LevereraKundAvisering.Avisering.V9/leka-extern-avisering/v9/aktorer/{aktorsId}/aviseringar
```

URL-schemat och -auktoriteten som används av samtliga utav produktionsmiljöns operationer är alltså `https://fmansinfo.forsakringskassan.se:7020/rest`. Denna typ av URL referas också till som _inlämningsadress_ i övrig dokumentation för LEFI Online.

#### 2.1.2 Header "Content-Type"

Kontrollera att headern ’Content-Type: application/json’ är satt i anropet till tjänsten, annars går det fel redan i integrationen.

